==> xcache-1.3.0p0.tgz: xcache/admin/common-zh-simplified-utf-8.lang.php <==
<?php

$strings = array(
		'Cache Legends'
		=> 'Cache 帮助',
		'List Legends'
		=> 'List 帮助',
		'XCache Administration Help'
		=> 'XCache 管理页面帮助信息',
		'Help'
		=> '帮助',
		'Slots'
		=> '槽',
		'Size'
		=> '大小',
		'Avail'
		=> '剩余',
		'Used'
		=> '已用',
		'Clear'
		=> '清除',
		'Sure to clear?'
		=> '确认要清除吗?',
		'Compiling'
		=> '编译中',
		'% Free'
		=> '% 剩余',
		'% Used'
		=> '% 已用',
		'Hits'
		=> '命中',
		'Hits 24H'
		=> '24H 分布',
		'Hits/H'
		=> '命中/H',
		'Hits/S'
		=> '命中/S',
		'Misses'
		=> '错过',
		'Clogs'
		=> '阻塞',
		'OOMs'
		=> '内存不足',
		'Errors'
		=> '错误',
		'Protected'
		=> '保护',
		'Cached'
		=> '缓存',
		'Deleted'
		=> '待删',
		'Delete'
		=> '删除',
		'Free Blocks'
		=> '空闲块',

		'entry'
		=> '项目',
		'Refcount'
		=> '引用数',
		'SrcSize'
		=> '源大小',
		'Modify'
		=> '修改',
		'device'
		=> '设备',
		'inode'
		=> 'Inode',
		'hash'
		=> 'Hash',
		'Access'
		=> '访问',
		'Create'
		=> '创建',
		'See also'
		=> '建议参考',
		'GC'
		=> 'GC',
		'Legends:'
		=> '图例:',
		'Used Blocks'
		=> '已用块',
		'Free Blocks'
		=> '未用块',
		'Total'
		=> '总共',
		'Cache'
		=> '缓冲区',
		'Caches'
		=> '缓冲区',
		'Cached'
		=> '缓冲',
		'php Cached'
		=> '缓冲的 php 脚本',
		'php Deleted'
		=> '待删 php 脚本',
		'var Cached'
		=> '缓冲的变量',
		'var Deleted'
		=> '待删变量',
		'Statistics'
		=> '摘要统计',
		'List PHP'
		=> '列出PHP',
		'List Var Data'
		=> '列变量数据',
		'XCache %s Administration'
		=> 'XCache %s 管理页面',
		'size'
		=> '大小',
		'offset'
		=> '位置',
		'Module Info'
		=> '模块信息',
		'Remove Selected'
		=> '删除所选',
		'Editing Variable %s'
		=> '正在编辑变量 %s',
		''
		=> '',
		);

==> xcache-2.0.1.tgz: xcache/admin/common-zh-simplified-utf-8.lang.php <==
<?php

$strings = array(
		'Cache Legends'
		=> 'Cache 帮助',
		'List Legends'
		=> 'List 帮助',
		'XCache Administration Help'
		=> 'XCache 管理页面帮助信息',
		'Help'
		=> '帮助',
		'Slots'
		=> '槽',
		'Size'
		=> '大小',
		'Avail'
		=> '剩余',
		'Used'
		=> '已用',
		'Clear'
		=> '清除',
		'Sure to clear?'
		=> '确认要清除吗?',
		'Compiling'
		=> '编译中',
		'% Free'
		=> '% 剩余',
		'% Used'
		=> '% 已用',
		'Hits'
		=> '命中',
		'Hits 24H'
		=> '24H 分布',
		'Hits/H'
		=> '命中/H',
		'Hits/S'
		=> '命中/S',
		'Updates'
		=> '更新',
		'Clogs'
		=> '阻塞',
		'OOMs'
		=> '内存不足',
		'Errors'
		=> '错误',
		'Protected'
		=> '保护',
		'Cached'
		=> '缓存',
		'Deleted'
		=> '待删',
		'Delete'
		=> '删除',
		'Free Blocks'
		=> '空闲块',

		'entry'
		=> '项目',
		'Refcount'
		=> '引用数',
		'PhpShared'
		=> '共享',
		'SrcSize'
		=> '源大小',
		'Modify'
		=> '修改',
		'device'
		=> '设备',
		'inode'
		=> 'Inode',
		'hash'
		=> 'Hash',
		'Access'
		=> '访问',
		'Create'
		=> '创建',
		'See also'
		=> '建议参考',
		'GC'
		=> 'GC',
		'Legends:'
		=> '图例:',
		'Used Blocks'
		=> '已用块',
		'Free Blocks'
		=> '未用块',
		'Total'
		=> '总共',
		'Cache'
		=> '缓冲区',
		'Caches'
		=> '缓冲区',
		'Cached'
		=> '缓冲',
		'php Cached'
		=> '缓冲的 php 脚本',
		'php Deleted'
		=> '待删 php 脚本',
		'var Cached'
		=> '缓冲的变量',
		'var Deleted'
		=> '待删变量',
		'Statistics'
		=> '摘要统计',
		'List PHP'
		=> '列出PHP',
		'List Var Data'
		=> '列变量数据',
		'XCache %s Administration'
		=> 'XCache %s 管理页面',
		'size'
		=> '大小',
		'offset'
		=> '位置',
		'Module Info'
		=> '模块信息',
		'Remove Selected'
		=> '删除所选',
		'Editing Variable %s'
		=> '正在编辑变量 %s',
		'Set %s in config to enable'
		=> '请在配置文件中设置 %s 启用本功能',
		''
		=> '',
		);
